﻿using FabAccessAPI.Schema;
using System;

namespace FabAccessAPI
{
    public interface IAPI
    {
        /// <summary>
        /// Data to establish connection.
        /// </summary>
        /// Without SecretProperties
        ConnectionData ConnectionData { get; }

        /// <summary>
        /// Information about the established connection.
        /// </summary>
        ConnectionInfo ConnectionInfo { get; }

        /// <summary>
        /// Is API connected?
        /// </summary>
        bool IsConnected { get; }

        /// <summary>
        /// Get session when connection is established
        /// </summary>
        Session Session { get; }

        /// <summary>
        /// Event on changes in connection state.
        /// </summary>
        event EventHandler<ConnectionStatusChange> ConnectionStatusChanged;

        /// <summary>
        /// Connect to BFFH Server
        /// </summary>
        /// <param name="connectionData"></param>
        void Connect(ConnectionData connectionData);

        /// <summary>
        /// Disconnect from BFFH Server
        /// </summary>
        void Disconnect();

        /// <summary>
        /// Reconnect after connection loss with the last ConnectionData
        /// </summary>
        void Reconnect();

        /// <summary>
        /// Connect to Server and get ConnectionInfo.
        /// The Connection is not maintained.
        /// </summary>
        ConnectionInfo TestConnection(ConnectionData connectionData);
    }
}
